==> pipewire-docs-1%3A1.4.9-2-x86_64.pkg.tar.zst: usr/share/doc/pipewire/html/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "PipeWire", "index.html", [
    [ "Overview", "page_overview.html", null ],
    [ "Configuration", "page_config.html", "page_config" ],
    [ "Programs", "page_programs.html", "page_programs" ],
    [ "Modules", "page_modules.html", "page_modules" ],
    [ "Pulseaudio Modules", "page_pulse_modules.html", "page_pulse_modules" ],
    [ "Internals", "page_internals.html", "page_internals" ],
    [ "PipeWire API", "page_api.html", "page_api" ],
    [ "API Tutorial", "page_tutorial.html", "page_tutorial" ],
    [ "API Reference", "topics.html", "topics" ],
    [ "Data Structures", "annotated.html", [
      [ "Data Structures", "annotated.html", "annotated_dup" ],
      [ "Data Structure Index", "classes.html", null ]
    ] ],
    [ "Examples", "examples.html", "examples" ],
    [ "PipeWire Versions", "usergroup0.html", [
      [ "1.2.x", "^https://docs.pipewire.org/1.2/", null ],
      [ "1.4.x", "^https://docs.pipewire.org/1.4/", null ],
      [ "Development", "^https://docs.pipewire.org/devel/", null ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"aac-types_8h.html",
"group__pw__core.html#gaab5fd68faa350ca3f2928032b0553a3f",
"group__pw__impl__module.html#gad0e64478bc2c8627547647a8fd689fe9",
"group__pw__link.html#ga5d3c859845886244df9d51621460f53b",
"group__pw__pipewire.html#gaf3d7686492ea5032eb135cddf21d3da2",
"group__pw__session__manager.html#ga659e95476b1273ad6b2d247256375df7",
"group__spa__ansi.html#ga5d126113edfe9df70eb7f68a6f874c85",
"group__spa__debug.html#gacf73547467a56c46de4420706bfb7023",
"group__spa__json.html#gab53b53bef4f8a982653cd074df6ea3ad",
"group__spa__names.html#gac2d9defa0b11f106341260bc879a3d91",
"group__spa__param.html#ga32bd31fd6ae92d81a05f6da2e718ec7d",
"group__spa__param.html#gae5c72d19b8d82d192d528cc927d648c7",
"group__spa__param.html#gga4077adc9cb334bd78d561f96c04eebbcadec07f884297fb3e8f33fad9b10f0fec",
"group__spa__param.html#ggacb274daea0abcce261955323e7d0b1aaa2454ceb1cd0a3903a75d4c95e4a8c1fe",
"group__spa__pod.html#ga2d61a450e8328ebca28a7ac49850840f",
"group__spa__ringbuffer.html#gaa049c4f76b7818538e2e41adb471d6b4",
"h264_8h.html",
"page_pulse_module_tunnel_source.html",
"structpw__device__events.html",
"structpw__memblock.html#a4731883fd9899d0d668c0f44a16d3b33",
"structspa__audio__aec__methods.html#a1d1c3a7ec1bd783ddb3cea31bc421cb1",
"structspa__graph__node.html#a6664b3c60baddc151a340bf2ebb3a5a2",
"structspa__node__events.html#a4b3918e0034bb87549fe911028ca8741",
"structspa__thread__utils__methods.html#aa0c4c049d9406510ff457400df373ceb"
];

var SYNCONMSG = 'click to disable panel synchronization';
var SYNCOFFMSG = 'click to enable panel synchronization';
var LISTOFALLMEMBERS = 'List of all members';

==> pipewire-docs-1%3A1.6.0-1-x86_64.pkg.tar.zst: usr/share/doc/pipewire/html/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "PipeWire", "index.html", [
    [ "Overview", "page_overview.html", null ],
    [ "Configuration", "page_config.html", "page_config" ],
    [ "Programs", "page_programs.html", "page_programs" ],
    [ "Modules", "page_modules.html", "page_modules" ],
    [ "Pulseaudio Modules", "page_pulse_modules.html", "page_pulse_modules" ],
    [ "Internals", "page_internals.html", "page_internals" ],
    [ "PipeWire API", "page_api.html", "page_api" ],
    [ "API Tutorial", "page_tutorial.html", "page_tutorial" ],
    [ "API Reference", "topics.html", "topics" ],
    [ "Data Structures", "annotated.html", [
      [ "Data Structures", "annotated.html", "annotated_dup" ],
      [ "Data Structure Index", "classes.html", null ]
    ] ],
    [ "Examples", "examples.html", "examples" ],
    [ "PipeWire Versions", "usergroup0.html", [
      [ "1.2.x", "^https://docs.pipewire.org/1.2/", null ],
      [ "1.4.x", "^https://docs.pipewire.org/1.4/", null ],
      [ "Development", "^https://docs.pipewire.org/devel/", null ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"aac-types_8h.html",
"group__pw__core.html#ga844067d3c4ee799eebb94db3d3c29e09",
"group__pw__impl__metadata.html#gaa6f28989938dc595ccded5afe5d0c709",
"group__pw__keys.html#gaf4643e961de004488943e2ab0322ac4c",
"group__pw__permission.html#ga4564637816ca41369b383af05951a3b7",
"group__pw__session__manager.html#ga31cff50a1b1c9652e16d4666b39f890a",
"group__pw__utils.html#ga97004c44df1cac3ac75257c40ff8ce58",
"group__spa__debug.html#ga136cf4d2d230a5f6deae8e2b386c3bee",
"group__spa__interfaces.html#gaf9eef5cf634711b4de82fc5f9e3802ee",
"group__spa__names.html#ga010bfd1f2c50f4927df733f5f13e5690",
"group__spa__param.html#ga043c422a1329d7456fec05aba5ec9710",
"group__spa__param.html#ga9ee7ee937054acf61c0fa3b0943508c4",
"group__spa__param.html#gga339d759aafadca6ef623f32ce7e65be0a871dcd85dad60d460bbad9176d23d048",
"group__spa__param.html#gga741ca54fc7f93308779660120bbed31eafe30d2fb50cb6f7a1964877b073252a1",
"group__spa__param.html#ggad544eabde6eb05d43433b18e78f9c5d1a5012d63db372da6a3e3f046e3ea63cea",
"group__spa__pod.html#ga582fb9a481313638185ce6f158eda737",
"group__spa__ringbuffer.html#gad620fa22ac4d12b7f482e50525e1242f",
"h264_8h.html",
"page_pulse_module_roc_source.html",
"structpw__core__methods.html#a23e319c72a886a40464d74e2e19f27f9",
"structpw__loop.html#a639de0bfd74cf9e292932aaed15182c5",
"structpw__timer.html",
"structspa__event.html#a1cfdf789b23f6f0ba623f3fc973951bb",
"structspa__loop__utils__methods.html#acb650a30486b87fcab5859afd000d913",
"structspa__result__node__params__data.html"
];

var SYNCONMSG = 'click to disable panel synchronization';
var SYNCOFFMSG = 'click to enable panel synchronization';
var LISTOFALLMEMBERS = 'List of all members';
